==> jira-api-8.4.2-sources.jar: com/atlassian/jira/issue/index/indexers/impl/VersionCustomFieldIndexer.java <==
package com.atlassian.jira.issue.index.indexers.impl;

import com.atlassian.jira.issue.Issue;
import com.atlassian.jira.issue.fields.CustomField;
import com.atlassian.jira.project.version.Version;
import com.atlassian.jira.web.FieldVisibilityManager;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.apache.lucene.document.SortedSetDocValuesField;
import org.apache.lucene.document.StoredField;
import org.apache.lucene.document.StringField;
import org.apache.lucene.util.BytesRef;

import java.util.Collection;

import static com.atlassian.jira.util.dbc.Assertions.notNull;

/**
 * A simple version custom field indexer.
 *
 * @since v4.0
 */
public class VersionCustomFieldIndexer extends AbstractCustomFieldIndexer {
    private final CustomField customField;

    public VersionCustomFieldIndexer(final FieldVisibilityManager fieldVisibilityManager, final CustomField customField) {
        super(fieldVisibilityManager, notNull("customField", customField));
        this.customField = customField;
    }

    public void addDocumentFieldsSearchable(final Document doc, final Issue issue) {
        addDocumentFields(doc, issue, true);
    }

    public void addDocumentFieldsNotSearchable(final Document doc, final Issue issue) {
        addDocumentFields(doc, issue, false);
    }

    public void addDocumentFields(final Document doc, final Issue issue, final boolean searchable) {
        final Object value = customField.getValue(issue);
        if (value != null && value instanceof Collection) {
            // NOTE: we make the assumption here that the value returned from the custom field is a collection of versions
            // because that is what is returned by VersionCFType#getValue()
            Collection<Version> versions = (Collection<Version>) value;
            for (final Version version : versions) {
                if (searchable) {
                    doc.add(new StringField(getDocumentFieldId(), version.getId().toString(), Field.Store.YES));
                    doc.add(new SortedSetDocValuesField(getDocumentFieldId(), new BytesRef(version.getId().toString())));
                } else {
                    doc.add(new StoredField(getDocumentFieldId(), version.getId().toString()));
                }
            }
        }
    }
}

==> jira-api-8.20.2-sources.jar: com/atlassian/jira/issue/index/indexers/impl/VersionCustomFieldIndexer.java <==
package com.atlassian.jira.issue.index.indexers.impl;

import com.atlassian.jira.issue.Issue;
import com.atlassian.jira.issue.fields.CustomField;
import com.atlassian.jira.project.version.Version;
import com.atlassian.jira.web.FieldVisibilityManager;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.apache.lucene.document.SortedSetDocValuesField;
import org.apache.lucene.document.StoredField;
import org.apache.lucene.document.StringField;
import org.apache.lucene.util.BytesRef;

import java.util.Collection;

import static com.atlassian.jira.util.dbc.Assertions.notNull;

/**
 * A simple version custom field indexer.
 *
 * @since v4.0
 */
public class VersionCustomFieldIndexer extends AbstractCustomFieldIndexer {
    public VersionCustomFieldIndexer(final FieldVisibilityManager fieldVisibilityManager, final CustomField customField) {
        super(fieldVisibilityManager, notNull("customField", customField));
    }

    public void addDocumentFieldsSearchable(final Document doc, final Issue issue) {
        addDocumentFields(doc, issue, true);
    }

    public void addDocumentFieldsNotSearchable(final Document doc, final Issue issue) {
        addDocumentFields(doc, issue, false);
    }

    @Override
    public Boolean skipsIndexingNull() {
        return true;
    }

    public void addDocumentFields(final Document doc, final Issue issue, final boolean searchable) {
        final Object value = customField.getValue(issue);
        if (value instanceof Collection) {
            // NOTE: we make the assumption here that the value returned from the custom field is a collection of versions
            // because that is what is returned by VersionCFType#getValue()
            Collection<Version> versions = (Collection<Version>) value;
            for (final Version version : versions) {
                if (searchable) {
                    doc.add(new StringField(getDocumentFieldId(), version.getId().toString(), Field.Store.YES));
                    doc.add(new SortedSetDocValuesField(getDocumentFieldId(), new BytesRef(version.getId().toString())));
                } else {
                    doc.add(new StoredField(getDocumentFieldId(), version.getId().toString()));
                }
            }
        }
    }
}
